@@ -27,14 +27,16 @@ class EnclosureAdmin(admin.ModelAdmin):
 admin.site.register(Enclosure, EnclosureAdmin)
 
 class FeedAdmin(admin.ModelAdmin):
-    list_display = ("title", "url", "blog", "language", "generator",
-                    "category")
+    list_display = ("title", "url", "blog", "language",
+        "category", "etag", "last_modified", "last_checked", "is_active")
     list_filter = ("language", "generator", "category")
+    search_fields = ["title", "url", "blog__title"]
 
 admin.site.register(Feed, FeedAdmin)
 
 class AuthorAdmin(admin.ModelAdmin):
     list_display = ("name", "email")
+    search_fields = ["name"]
 
 admin.site.register(Author, AuthorAdmin)
 
@@ -43,15 +45,16 @@ class EnclosureInline(admin.StackedInline):
     extra = 0
 
 class PostAdmin(admin.ModelAdmin):
-    list_display = ("title", "feed", "url")
+    list_display = ("title", "feed", "guid", "date_created", "date_modified")
     list_filter = ("feed", )
-    # filter_horizontal = ('tags',)
+    search_fields = ["title", "feed__blog__title"]
 
 admin.site.register(Post, PostAdmin, inlines=[EnclosureInline])
 
 
 class BlogAdmin(admin.ModelAdmin):
-    list_display = ("title", "url")
+    list_display = ("title", "url", "date_created")
+    search_fields = ["title", "url"]
 
 admin.site.register(Blog, BlogAdmin)
 
@@ -70,5 +73,6 @@ admin.site.register(FeedLink, FeedLinkAdmin)
 
 class CategoryAdmin(admin.ModelAdmin):
     list_display = ("title", )
+    search_fields = ["title"]
 
-admin.site.register(Category, CategoryAdmin)
\ No newline at end of file
+admin.site.register(Category, CategoryAdmin)
