@@ -9,6 +9,11 @@
     [1] http://www.feedjack.org/
     [2] http://www.feedparser.org/
 """
+
+# python 3.x compatibility helpers
+from __future__ import unicode_literals
+from django.utils.encoding import python_2_unicode_compatible
+
 import feedparser
 from datetime import datetime
 
@@ -27,6 +32,7 @@ from planet.managers import (FeedManager, AuthorManager, BlogManager,
     EnclosureManager)
 
 
+@python_2_unicode_compatible
 class Blog(models.Model):
     """
     A model to store primary info about a blog or website that which feed or
@@ -44,8 +50,8 @@ class Blog(models.Model):
         verbose_name_plural = _("Blogs")
         ordering = ('title', 'url',)
 
-    def __unicode__(self):
-        return u'%s (%s)' % (self.title, self.url)
+    def __str__(self):
+        return '{} ({})'.format(self.title, self.url)
 
     @models.permalink
     def get_absolute_url(self):
@@ -55,6 +61,7 @@ class Blog(models.Model):
         return slugify(self.title) or "no-title"
 
 
+@python_2_unicode_compatible
 class Generator(models.Model):
     """
     The software or website that has built a feed
@@ -72,10 +79,11 @@ class Generator(models.Model):
         ordering = ('name', 'version',)
         unique_together = (("name", "link", "version"), )
 
-    def __unicode__(self):
-        return u'%s %s (%s)' % (self.name, self.version or "", self.link or "--")
+    def __str__(self):
+        return '{} {} ({})'.format(self.name, self.version or "", self.link or "--")
 
 
+@python_2_unicode_compatible
 class Category(models.Model):
     """
     Define Categories for Feeds. In this way a site can manage many
@@ -89,10 +97,11 @@ class Category(models.Model):
         verbose_name_plural = _("Feed Categories")
         ordering = ('title', 'date_created')
 
-    def __unicode__(self):
-        return u"%s" % (self.title,)
+    def __str__(self):
+        return "{}".format(self.title)
 
 
+@python_2_unicode_compatible
 class Feed(models.Model):
     """
     A model to store detailed info about a parsed Atom or RSS feed
@@ -158,7 +167,7 @@ class Feed(models.Model):
             try:
                 USER_AGENT = settings.PLANET["USER_AGENT"]
             except (KeyError, AttributeError):
-                print """Please set the PLANET = {"USER_AGENT": <string>} in your settings.py"""
+                print("""Please set the PLANET = {"USER_AGENT": <string>} in your settings.py""")
                 exit(0)
 
             document = feedparser.parse(self.url, agent=USER_AGENT,
@@ -192,8 +201,8 @@ class Feed(models.Model):
                 self.generator = None
         super(Feed, self).save(*args, **kwargs)
 
-    def __unicode__(self):
-        return u'%s (%s)' % (self.title, self.url)
+    def __str__(self):
+        return '{} ({})'.format(self.title, self.url)
 
     @models.permalink
     def get_absolute_url(self):
@@ -203,6 +212,7 @@ class Feed(models.Model):
         return slugify(self.title) or "no-title"
 
 
+@python_2_unicode_compatible
 class PostAuthorData(models.Model):
     """
     This is the intermediate model that holds the information of the post authors
@@ -219,12 +229,13 @@ class PostAuthorData(models.Model):
         verbose_name_plural = _("Post Author Data")
         ordering = ("author", "post", "is_contributor")
 
-    def __unicode__(self):
+    def __str__(self):
         author_type = self.is_contributor and "Contributor" or "Author"
-        return u'%s (%s - %s)' % (
+        return '{} ({} - {})'.format(
             self.author.name, author_type, self.post.title)
 
 
+@python_2_unicode_compatible
 class Post(models.Model):
     """
     A feed contains a collection of posts. This model stores them.
@@ -250,8 +261,8 @@ class Post(models.Model):
         ordering = ('-date_created', '-date_modified')
         unique_together = (('feed', 'guid'),)
 
-    def __unicode__(self):
-        return u"%s [%s]" % (self.title, self.feed.title)
+    def __str__(self):
+        return "{} [{}]".format(self.title, self.feed.title)
 
     @models.permalink
     def get_absolute_url(self):
@@ -269,6 +280,7 @@ def delete_asociated_tags(sender, **kwargs):
 pre_delete.connect(delete_asociated_tags, sender=Post)
 
 
+@python_2_unicode_compatible
 class Author(models.Model):
     """
     An author is everyone who wrote or has contributed to write a post.
@@ -286,8 +298,8 @@ class Author(models.Model):
         verbose_name_plural = _("Authors")
         ordering = ('name', 'email')
 
-    def __unicode__(self):
-        return u"%s (%s)" % (self.name, self.email,)
+    def __str__(self):
+        return "{} ({})".format(self.name, self.email)
 
     @models.permalink
     def get_absolute_url(self):
@@ -297,6 +309,7 @@ class Author(models.Model):
         return slugify(self.name) or "no-title"
 
 
+@python_2_unicode_compatible
 class FeedLink(models.Model):
     """
     Stores data contained in feedparser's feed.links for a given feed
@@ -315,8 +328,8 @@ class FeedLink(models.Model):
         ordering = ("feed", "rel", "mime_type")
         #unique_together = (("feed", "rel", "mime_type", "link"), )
 
-    def __unicode__(self):
-        return u"%s %s (%s)" % (self.feed.title, self.rel, self.mime_type)
+    def __str__(self):
+        return "{} {} ({})".format(self.feed.title, self.rel, self.mime_type)
 
 
 class PostLink(models.Model):
@@ -338,10 +351,11 @@ class PostLink(models.Model):
         ordering = ("post", "title", "rel")
         #unique_together = (("post", "rel", "mime_type", "title"), )
 
-    def __unicode__(self):
-        return u"%s %s (%s)" % (self.title, self.rel, self.post)
+    def __str__(self):
+        return "{} {} ({})".format(self.title, self.rel, self.post)
 
 
+@python_2_unicode_compatible
 class Enclosure(models.Model):
     """
     Stores data contained in feedparser's feed.entries[i].enclosures for a given feed
@@ -360,6 +374,6 @@ class Enclosure(models.Model):
         ordering = ("post", "mime_type", "link")
         #unique_together = (("post", "link", "mime_type"), )
 
-    def __unicode__(self):
-        return u"%s [%s] (%s)" % (self.link, self.mime_type, self.post)
+    def __str__(self):
+        return "{} [{}] ({})".format(self.link, self.mime_type, self.post)
 
